
Wutta-Continuum
===============

This package adds data versioning/history for `WuttJamaican`_, using
`SQLAlchemy-Continuum`_.

.. _WuttJamaican: https://rattailproject.org/docs/wuttjamaican/

.. _SQLAlchemy-Continuum: https://sqlalchemy-continuum.readthedocs.io/en/latest/

.. image:: https://img.shields.io/badge/linting-pylint-yellowgreen
    :target: https://github.com/pylint-dev/pylint

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black


.. toctree::
   :maxdepth: 2
   :caption: Documentation

   narr/install

.. toctree::
   :maxdepth: 1
   :caption: API

   api/wutta_continuum
   api/wutta_continuum.app
   api/wutta_continuum.conf
   api/wutta_continuum.testing
   api/wutta_continuum.util
